# Vendored dependencies

The code files in this directory are third-party 'vendor' dependencies used by the various test applications.

⚠&#xFE0F; They are **not** required for regular use of toml++.

⚠&#xFE0F; They are **not** `#included` anywhere in toml++.
